@@ -156,8 +156,8 @@ static int __smp_thread_id(void)
 			return i;
 	}
 	spin_unlock(&__thread_id_map_mutex);
-	fprintf(stderr, "smp_thread_id: Rogue thread, id: %d(%#x)\n",
-			(int)tid, (int)tid);
+	fprintf(stderr, "smp_thread_id: Rogue thread, id: %lu(%#lx)\n",
+			(unsigned long) tid, (unsigned long) tid);
 	exit(-1);
 }
 
@@ -206,8 +206,8 @@ static void *wait_thread(thread_id_t tid)
 			break;
 	}
 	if (i >= NR_THREADS){
-		fprintf(stderr, "wait_thread: bad tid = %d(%#x)\n",
-				(int)tid, (int)tid);
+		fprintf(stderr, "wait_thread: bad tid = %lu(%#lx)\n",
+				(unsigned long)tid, (unsigned long)tid);
 		exit(-1);
 	}
 	if (pthread_join(tid, &vp) != 0) {
