@@ -44,7 +44,7 @@ for BATCH_SIZE in ${BATCH_ARRAY}; do
 done
 
 #setting gc each 32768. ** UPDATE FOR YOUR ARCHITECTURE BASED ON TEST ABOVE **
-EXTRA_OPTS+="-b 32768"
+EXTRA_OPTS="${EXTRA_OPTS} -b 32768"
 
 echo Executing update fraction test
 
