@@ -91,7 +91,8 @@ void *thr_reader(void *arg)
 	long tidx = (long)arg;
 
 	printf("thread_begin %s, thread id : %lx, tid %lu\n",
-			"reader", pthread_self(), (unsigned long)gettid());
+			"reader", (unsigned long) pthread_self(),
+			(unsigned long) gettid());
 	sleep(2);
 
 	time1 = caa_get_cycles();
@@ -108,7 +109,8 @@ void *thr_reader(void *arg)
 
 	sleep(2);
 	printf("thread_end %s, thread id : %lx, tid %lu\n",
-			"reader", pthread_self(), (unsigned long)gettid());
+			"reader", (unsigned long) pthread_self(),
+			(unsigned long) gettid());
 	return ((void*)1);
 
 }
@@ -120,7 +122,8 @@ void *thr_writer(void *arg)
 	cycles_t time1, time2;
 
 	printf("thread_begin %s, thread id : %lx, tid %lu\n",
-			"writer", pthread_self(), (unsigned long)gettid());
+			"writer", (unsigned long) pthread_self(),
+			(unsigned long) gettid());
 	sleep(2);
 
 	for (i = 0; i < OUTER_WRITE_LOOP; i++) {
@@ -140,7 +143,8 @@ void *thr_writer(void *arg)
 	}
 
 	printf("thread_end %s, thread id : %lx, tid %lu\n",
-			"writer", pthread_self(), (unsigned long)gettid());
+			"writer", (unsigned long) pthread_self(),
+			(unsigned long) gettid());
 	return ((void*)2);
 }
 
@@ -166,7 +170,8 @@ int main(int argc, char **argv)
 	tid_writer = malloc(sizeof(*tid_writer) * num_write);
 
 	printf("thread %-6s, thread id : %lx, tid %lu\n",
-			"main", pthread_self(), (unsigned long)gettid());
+			"main", (unsigned long) pthread_self(),
+			(unsigned long) gettid());
 
 	per_thread_lock = malloc(sizeof(struct per_thread_lock) * NR_READ);
 
