@@ -28,9 +28,9 @@
 extern "C" {
 #endif
 
-#define cmm_mb()			asm volatile("mb":::"memory")
-#define cmm_wmb()			asm volatile("wmb":::"memory")
-#define cmm_read_barrier_depends()	asm volatile("mb":::"memory")
+#define cmm_mb()			__asm__ __volatile__ ("mb":::"memory")
+#define cmm_wmb()			__asm__ __volatile__ ("wmb":::"memory")
+#define cmm_read_barrier_depends()	__asm__ __volatile__ ("mb":::"memory")
 
 typedef unsigned long long cycles_t;
 
