@@ -24,7 +24,7 @@
 #define caa_likely(x)	__builtin_expect(!!(x), 1)
 #define caa_unlikely(x)	__builtin_expect(!!(x), 0)
 
-#define	cmm_barrier()	asm volatile("" : : : "memory")
+#define	cmm_barrier()	__asm__ __volatile__ ("" : : : "memory")
 
 /*
  * Instruct the compiler to perform only a single access to a variable
@@ -38,7 +38,7 @@
  * use is to mediate communication between process-level code and irq/NMI
  * handlers, all running on the same CPU.
  */
-#define CMM_ACCESS_ONCE(x)	(*(volatile typeof(x) *)&(x))
+#define CMM_ACCESS_ONCE(x)	(*(__volatile__  __typeof__(x) *)&(x))
 
 #ifndef caa_max
 #define caa_max(a,b) ((a)>(b)?(a):(b))
@@ -65,12 +65,12 @@
  */
 #define caa_container_of(ptr, type, member)				\
 	({								\
-		const typeof(((type *) NULL)->member) * __ptr = (ptr);	\
+		const __typeof__(((type *) NULL)->member) * __ptr = (ptr); \
 		(type *)((char *)__ptr - offsetof(type, member));	\
 	})
 
 #define CAA_BUILD_BUG_ON_ZERO(cond) (sizeof(struct { int:-!!(cond); }))
-#define CAA_BUILD_BUG_ON(cond) ((void)BUILD_BUG_ON_ZERO(cond))
+#define CAA_BUILD_BUG_ON(cond) ((void)CAA_BUILD_BUG_ON_ZERO(cond))
 
 /*
  * __rcu is an annotation that documents RCU pointer accesses that need
